<?php 
    /**
     * Load the Js required to init the ratings and review code from Amazon. 
     * This needs to load last after all widget code. 
     */
    add_action( 'woocommerce_after_single_product', 'abwp_load_amazon_js', 6 );
    function abwp_load_amazon_js() {
        // Make sure this plugin is enabled before loading any JS code.
        if (abwp_plugin_status() != 0) {
            echo "
                <!-- Beginning of Buy With Prime Widget -->
                <script async fetchpriority='high' src='https://code.buywithprime.amazon.com/bwp.js'></script>
                <!-- End of Buy With Prime Widget -->
            ";
        }
    }

    /**
     * Check if this plugin is disabled  
     */
    function abwp_plugin_status() {
        $status = 0;
        if (!empty(get_option( 'abwp_ratings_html' )) && get_option( 'abwp_rating_location' ) != 'disabled' ) {
            $status = 1;
        }
        if (!empty(get_option( 'abwp_reviews_html' )) && get_option( 'abwp_review_location' ) != 'disabled' ) {
            $status = 1;
        }
        if (!empty(get_option( 'abwp_button_html' )) && get_option( 'abwp_button_location' ) != 'disabled' ) {
            $status = 1;
        }
        return $status;
    }

    /**
     * Inject the Amazon Product Rating in the woocommerce template, based on admin settings.
     */
    add_action( 'template_redirect', 'abwp_load_amazon_rating' );
    function abwp_load_amazon_rating() {
        if (!empty(get_option( 'abwp_ratings_html' )) && get_option( 'abwp_rating_location' ) != 'disabled' ) {
            $location = get_option( 'abwp_rating_location' );
            if ($location == 'before_product_title') {
                add_action( 'woocommerce_single_product_summary', 'abwp_load_amazon_rating_html', 1 );
            }
            if ($location == 'after_product_title') {
                add_action( 'woocommerce_single_product_summary', 'abwp_load_amazon_rating_html', 6 );
            }
            if ($location == 'after_short_description') {
                add_action( 'woocommerce_before_add_to_cart_form', 'abwp_load_amazon_rating_html', 1 );
            }
            if ($location == 'before_add_to_cart') {
                add_action( 'woocommerce_before_add_to_cart_button', 'abwp_load_amazon_rating_html', 1 );
            }
            if ($location == 'after_add_to_cart') {
                add_action( 'woocommerce_after_add_to_cart_button', 'abwp_load_amazon_rating_html', 1 );
            }
        }
    }

    /**
     * Display the Amazon ratings 
     */
    function abwp_load_amazon_rating_html() { 
        global $product; 
        $product_sku = $product->get_sku();
        if (empty($product_sku) && current_user_can('administrator') ) {
            echo "<b>IMPORTANT:</b> This product will not display the Amazon Buy with Prime button because it does not have an SKU set.<br>";
            echo "<small>This message is only visible to logged in administrators.</small>";
            return;
        } 
        echo abwp_replace_product_sku(get_option( 'abwp_ratings_html' ), $product_sku);
    }

    /**
     * Replace the product sku in the amazon buy with prime code. 
     */
    function abwp_replace_product_sku( $string, $product_sku ) {
        $string = str_replace( '{{product.sku}}', $product_sku, $string );
        return $string;
    }

    /**
     * Inject the Amazon Product reviews in the woocommerce template, based on admin settings.
     */
    add_action( 'template_redirect', 'abwp_load_amazon_reviews' );
    function abwp_load_amazon_reviews() {
        if (!empty(get_option( 'abwp_reviews_html' )) && get_option( 'abwp_review_location' ) != 'disabled' ) {
            $location = get_option( 'abwp_review_location' );
            if ($location == 'replace') {
                // Replace the tab title because the review count from wordpress will not match amazon. 
                add_filter( 'woocommerce_product_tabs', 'adwp_rename_reviews_tab' );
                add_filter( 'woocommerce_product_tabs', 'abwp_replace_reviews_tab' );
            }
            //add_action( $location, 'abwp_load_amazon_review_html', 6 );
        }
    }

    /**
     * Inject the Amazon Buy With Prime Button.
     */
    add_action( 'template_redirect', 'abwp_load_amazon_button' );
    function abwp_load_amazon_button() {
        if (!empty(get_option( 'abwp_button_html' )) && get_option( 'abwp_button_location' ) != 'disabled' ) {
            $location = get_option( 'abwp_button_location' );
            if ($location == 'after_add_to_cart') {
                add_action( 'woocommerce_after_add_to_cart_button', 'abwp_load_amazon_button_html', 1 );
            }
            //add_action( $location, 'abwp_load_amazon_review_html', 6 );
        }
    }

    /**
     * Display the Amazon Button
     */
    function abwp_load_amazon_button_html() { 
        global $product; 
        $product_sku = $product->get_sku();
        if (empty($product_sku) && current_user_can('administrator') ) {
            echo "<b>IMPORTANT:</b> This product will not display the Amazon Buy with Prime button because it does not have an SKU set.<br>";
            echo "<small>This message is only visible to logged in administrators.</small>";
            return;
        } 
        echo abwp_replace_product_sku(get_option( 'abwp_button_html' ), $product_sku);
    }

    /**
     * Replace the default woocomerce reviews with Amazon Reviews. 
     */
    function abwp_replace_reviews_tab( $tabs ) {
        $tabs[ 'reviews' ][ 'callback' ] = 'abwp_load_amazon_review_html';
        return $tabs;
    }
    /**
     * Replace the default woocomerce reviews title.
     */
    function adwp_rename_reviews_tab( $tabs ) {
        $tabs[ 'reviews' ][ 'title' ] = 'Reviews';
        return $tabs;
    }

    /**
     * Display The Amazon Reviews
     */
    function abwp_load_amazon_review_html() { 
        global $product; 
        $product_sku = $product->get_sku();
        if (empty($product_sku) && current_user_can('administrator') ) {
            echo "<b>IMPORTANT:</b> This product will not display the Amazon Buy with Prime button because it does not have an SKU set.<br>";
            echo "<small>This message is only visible to logged in administrators.</small>";
            return;
        } 
        echo abwp_replace_product_sku(get_option( 'abwp_reviews_html' ), $product_sku);
    }
